#
# spec file for package arm-trusted-firmware-rk35xx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global platform %{nil}

%define srcversion 1.0.0
Name:           arm-trusted-firmware-%{platform}
Version:        %{srcversion}
Release:        1.8
Summary:        Arm Trusted Firmware-A for Rockchip 35xx SOCs
License:        SUSE-Firmware
Group:          System/Boot
URL:            https://github.com/rockchip-linux/rkbin
Source1:        binaries-rockchip-master.tar.xz
Source2:        arm-trusted-firmware-rk35xx-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildArch:      noarch
ExclusiveArch:  aarch64

%description
Trusted Firmware-A (TF-A) provides a reference implementation of secure world
software for Armv7-A and Armv8-A, including a Secure Monitor executing at
Exception Level 3 (EL3).

%prep
%setup -T -q -n binaries-rockchip-master -b 1

%build

%install

%if "%{platform}" == "rk3528"
%define rockchip_bl31          rk3528_bl31_v1.17.elf
%define rockchip_bl32          rk3528_bl32_v1.03.bin
%define rockchip_ddr           rk3528_ddr_1056MHz_v1.09.bin
%define rockchip_mcu           rk3528_mcu_v1.00.bin
%define rockchip_spl           rk3528_spl_v1.05.bin
%define rockchip_usbplug       rk3528_usbplug_v1.03.bin
%define rockchip_extra         rk3528_ddr_1056MHz_2L_PCB_v1.09.bin rk3528_ddr_1056MHz_4BIT_PCB_v1.09.bin
%endif

%if "%{platform}" == "rk3562"
%define rockchip_bl31          rk3562_bl31_v1.19.elf
%define rockchip_bl32          rk3562_bl32_v1.02.bin
%define rockchip_ddr           rk3562_ddr_1560MHz_v1.05.bin
%define rockchip_mcu           rk3562_mcu_v1.00.bin
%define rockchip_spl           rk356x_spl_v1.13.bin
%define rockchip_spl_nand      rk356x_spl_nand_v1.14.bin
%define rockchip_usbplug       rk356x_usbplug_v1.17.bin
%define rockchip_usbplug_nand  rk356x_usbplug_nand_v1.04.bin
%define rockchip_extra         rk3562_ddr_920MHz_v1.05.bin rk3562_ddr_1056MHz_ultra_v1.05.bin rk3562_ddr_1056MHz_v1.05.bin rk3562_ddr_1332MHz_eyescan_v1.04.bin rk3562_ddr_1332MHz_v1.05.bin rk3562_ddr_1392MHz_v1.05.bin rk3562_spl_v1.05.bin rk3562_spl_v1.06.bin rk3562_usbplug_v1.04.bin
%endif

%if "%{platform}" == "rk3566"
%define rockchip_ddr          rk3566_ddr_1056MHz_v1.21.bin
%define rockchip_spl          rk356x_spl_v1.13.bin
%define rockchip_spl_nand     rk356x_spl_nand_v1.14.bin
%define rockchip_usbplug      rk356x_usbplug_v1.17.bin
%define rockchip_usbplug_nand rk356x_usbplug_nand_v1.04.bin
%define rockchip_extra        rk3566_ddr_1056MHz_eyescan_v1.16.bin rk3566_ddr_1056MHz_ultra_v1.20.bin rk3566_ddr_528MHz_ultra_v1.10.bin rk3566_ddr_780MHz_ultra_v1.10.bin rk3566_ddr_920MHz_ultra_v1.10.bin rk3566_ddr_920MHz_v1.21.bin
%endif

%if "%{platform}" == "rk3568"
%define rockchip_bl31          rk3568_bl31_v1.44.elf
%define rockchip_bl32          rk3568_bl32_v2.11.bin
%define rockchip_ddr           rk3568_ddr_1560MHz_v1.21.bin
%define rockchip_pcie          rk3568_pcie_v2.10.bin
%define rockchip_miniloader    rk3568_miniloader_spinand_v1.15.bin
%define rockchip_ramboot       rk3568_ramboot_v1.08.bin
%define rockchip_spl           rk356x_spl_v1.13.bin
%define rockchip_spl_nand      rk356x_spl_nand_v1.14.bin
%define rockchip_usbplug       rk356x_usbplug_v1.17.bin
%define rockchip_usbplug_nand  rk356x_usbplug_nand_v1.04.bin
%define rockchip_extra         rk3568_bl31_cpu3_v1.01.elf rk3568_bl31_l3_part_ecc_v1.00.elf rk3568_bl31_rt_v1.02.elf rk3568_bl31_ultra_v2.17.elf rk3568_ddr_1056MHz_v1.21.bin rk3568_ddr_1332MHz_v1.21.bin rk3568_ddr_1560MHz_eyescan_v1.16.bin rk3568_ddr_920MHz_v1.21.bin rk3568_ramboot_null0.bin rk3568_ramboot_null1.bin
%endif

%if "%{platform}" == "rk3583"
%define rockchip_ddr        rk3583_ddr_lp4_1848MHz_lp5_2112MHz_v1.14.bin
%endif

%if "%{platform}" == "rk3588"
%define rockchip_bl31       rk3588_bl31_v1.45.elf
%define rockchip_bl32       rk3588_bl32_v1.15.bin
%define rockchip_ddr        rk3588_ddr_lp4_2112MHz_lp5_2400MHz_v1.16.bin
%define rockchip_pcie       rk3588_pcie_v2.10.bin
%define rockchip_ramboot    rk3588_ramboot_v1.06.bin
%define rockchip_spl        rk3588_spl_v1.13.bin
%define rockchip_usbplug    rk3588_usbplug_v1.11.bin
%define rockchip_extra      rk3588_ddr_lp4_2112MHz_lp5_2736MHz_eyescan_v1.11.bin rk3588_ramboot_null0.bin rk3588_ramboot_null1.bin
%endif

srcdir=%{_builddir}/binaries-rockchip-master/bin/rk35
destdir=%{buildroot}%{_datadir}/%{name}
mkdir -p "${destdir}"
# For each chip, create symlinks to the most current versions for BL31, BL32 etc.

pushd $destdir
if [[ "%{?rockchip_bl31}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_bl31} ./
    ln -s %{rockchip_bl31} bl31.elf
fi
if [[ "%{?rockchip_bl32}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_bl32} ./
    ln -s %{rockchip_bl32} bl32.bin
fi
if [[ "%{?rockchip_ddr}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_ddr} ./
    ln -s %{rockchip_ddr} rockchip-ddr.bin
    ln -s %{rockchip_ddr} uboot-board-tpl.bin
fi
if [[ "%{?rockchip_pcie}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_pcie} ./
    ln -s %{rockchip_pcie} rockchip-pcie.bin
fi
if [[ "%{?rockchip_mcu}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_mcu} ./
    ln -s %{rockchip_mcu} rockchip-mcu.bin
fi
if [[ "%{?rockchip_miniloader}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_miniloader} ./
    ln -s %{rockchip_miniloader} rockchip-miniloader.bin
fi
if [[ "%{?rockchip_ramboot}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_ramboot} ./
    ln -s %{rockchip_ramboot} rockchip-ramboot.bin
fi
if [[ "%{?rockchip_spl}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_spl} ./
    ln -s %{rockchip_spl} rockchip-spl.bin
fi
if [[ "%{?rockchip_spl_nand}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_spl_nand} ./
    ln -s %{rockchip_spl_nand} rockchip-spl_nand.bin
fi
if [[ "%{?rockchip_usbplug}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_usbplug} ./
    ln -s %{rockchip_usbplug} rockchip-usbplug.bin
fi
if [[ "%{?rockchip_usbplug_nand}" != "" ]]; then
    install -D -m 0644 ${srcdir}/%{rockchip_usbplug_nand} ./
    ln -s %{rockchip_usbplug_nand} rockchip-usbplug_nand.bin
fi

for fn in %{?rockchip_extra}; do
    install -D -m 0644 ${srcdir}/$fn %{buildroot}%{_datadir}/%{name}/
done
popd

%files
%defattr(-,root,root)
%license LICENSE
%{_datadir}/%{name}

%changelog
* Mon Mar 11 2024 kontakt@andreas-buschka.de
- Initial package version
